# mypy-boto3-iotsitewise

[![PyPI - mypy-boto3-iotsitewise](https://img.shields.io/pypi/v/mypy-boto3-iotsitewise.svg?color=blue)](https://pypi.org/project/mypy-boto3-iotsitewise)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-iotsitewise.svg?color=blue)](https://pypi.org/project/mypy-boto3-iotsitewise)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.IoTSiteWise 1.14.39](https://boto3.amazonaws.com/v1/documentation/api/1.14.39/reference/services/iotsitewise.html#IoTSiteWise) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `IoTSiteWise` service.

```bash
python -m pip install boto3-stubs[iotsitewise]
```

## How to use

### Client annotations

`IoTSiteWiseClient` provides annotations for `boto3.client("iotsitewise")`.

```python
import boto3

from mypy_boto3_iotsitewise import IoTSiteWiseClient
from mypy_boto3_iotsitewise.paginator import (
    GetAssetPropertyAggregatesPaginator,
    GetAssetPropertyValueHistoryPaginator,
    ListAccessPoliciesPaginator,
    ListAssetModelsPaginator,
    ListAssetsPaginator,
    ListAssociatedAssetsPaginator,
    ListDashboardsPaginator,
    ListGatewaysPaginator,
    ListPortalsPaginator,
    ListProjectAssetsPaginator,
    ListProjectsPaginator,
)
from mypy_boto3_iotsitewise.type_defs import AccessPolicySummaryTypeDef, ...
from mypy_boto3_iotsitewise.waiter import (
    AssetActiveWaiter,
    AssetModelActiveWaiter,
    AssetModelNotExistsWaiter,
    AssetNotExistsWaiter,
    PortalActiveWaiter,
    PortalNotExistsWaiter,
)

client: IoTSiteWiseClient = boto3.client("iotsitewise")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: IoTSiteWiseClient = session.client("iotsitewise")
```

### Paginators annotations

`mypy_boto3_iotsitewise.paginator` module contains type annotations for all paginators.

```python

client: IoTSiteWiseClient = boto3.client("iotsitewise")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_asset_property_aggregates_paginator: GetAssetPropertyAggregatesPaginator = client.get_paginator("get_asset_property_aggregates")
get_asset_property_value_history_paginator: GetAssetPropertyValueHistoryPaginator = client.get_paginator("get_asset_property_value_history")
list_access_policies_paginator: ListAccessPoliciesPaginator = client.get_paginator("list_access_policies")
list_asset_models_paginator: ListAssetModelsPaginator = client.get_paginator("list_asset_models")
list_assets_paginator: ListAssetsPaginator = client.get_paginator("list_assets")
list_associated_assets_paginator: ListAssociatedAssetsPaginator = client.get_paginator("list_associated_assets")
list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
list_portals_paginator: ListPortalsPaginator = client.get_paginator("list_portals")
list_project_assets_paginator: ListProjectAssetsPaginator = client.get_paginator("list_project_assets")
list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
```


### Waiters annotations

`mypy_boto3_iotsitewise.waiter` module contains type annotations for all waiters.

```python

client: IoTSiteWiseClient = boto3.client("iotsitewise")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
asset_active_waiter: AssetActiveWaiter = client.get_waiter("asset_active")
asset_model_active_waiter: AssetModelActiveWaiter = client.get_waiter("asset_model_active")
asset_model_not_exists_waiter: AssetModelNotExistsWaiter = client.get_waiter("asset_model_not_exists")
asset_not_exists_waiter: AssetNotExistsWaiter = client.get_waiter("asset_not_exists")
portal_active_waiter: PortalActiveWaiter = client.get_waiter("portal_active")
portal_not_exists_waiter: PortalNotExistsWaiter = client.get_waiter("portal_not_exists")
```





### Typed dictionations

`mypy_boto3_iotsitewise.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> AccessPolicySummaryTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_iotsitewise` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("iotsitewise")

session_client = boto3.Session().client("iotsitewise")
```
